==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicIconFactory__244.h <==
// final class javax.swing.plaf.basic.BasicIconFactory$4

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a234b9cb6e0e1ece javax_swing_plaf_basic_BasicIconFactory__244

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicIconFactory__244_H_
#define _JC_javax_swing_plaf_basic_BasicIconFactory__244_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$sub_refs	_jc_javax_swing_plaf_basic_BasicIconFactory__244$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicIconFactory__244$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$refs	_jc_javax_swing_plaf_basic_BasicIconFactory__244$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$nonrefs	_jc_javax_swing_plaf_basic_BasicIconFactory__244$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object	_jc_javax_swing_plaf_basic_BasicIconFactory__244$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$vmethods	_jc_javax_swing_plaf_basic_BasicIconFactory__244$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$vtable	_jc_javax_swing_plaf_basic_BasicIconFactory__244$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$vtype	_jc_javax_swing_plaf_basic_BasicIconFactory__244$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicIconFactory__244$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object *);

// Virtual methods
extern jint _jc_javax_swing_plaf_basic_BasicIconFactory__244$method$getIconHeight$50a8d095671b871d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object *);
extern jint _jc_javax_swing_plaf_basic_BasicIconFactory__244$method$getIconWidth$e4e0e0a5d8773e91(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object *);
extern void _jc_javax_swing_plaf_basic_BasicIconFactory__244$method$paintIcon$ec942e304ba768a4(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicIconFactory__244$method_info$getIconHeight$50a8d095671b871d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicIconFactory__244$method_info$getIconWidth$e4e0e0a5d8773e91;
extern _jc_method _jc_javax_swing_plaf_basic_BasicIconFactory__244$method_info$paintIcon$ec942e304ba768a4;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$vmethods {
	jint	(*getIconHeight$50a8d095671b871d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object *);
	jint	(*getIconWidth$e4e0e0a5d8773e91)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object *);
	void	(*paintIcon$ec942e304ba768a4)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicIconFactory__244$vmethods	javax_swing_plaf_basic_BasicIconFactory__244;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicIconFactory__244$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$refs {
    _jc_javax_swing_plaf_basic_BasicIconFactory__244$sub_refs	javax_swing_plaf_basic_BasicIconFactory__244;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicIconFactory__244$sub_nonrefs	javax_swing_plaf_basic_BasicIconFactory__244;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object {
	_jc_javax_swing_plaf_basic_BasicIconFactory__244$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicIconFactory__244$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicIconFactory__244$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicIconFactory__244$vtype _jc_javax_swing_plaf_basic_BasicIconFactory__244$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicIconFactory__244, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicIconFactory__244$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicIconFactory__244_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicIconFactory__244.h <==
// final class javax.swing.plaf.basic.BasicIconFactory$4

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a234b9cb6e0e1ece javax_swing_plaf_basic_BasicIconFactory__244

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicIconFactory__244_H_
#define _JC_javax_swing_plaf_basic_BasicIconFactory__244_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$sub_refs	_jc_javax_swing_plaf_basic_BasicIconFactory__244$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicIconFactory__244$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$refs	_jc_javax_swing_plaf_basic_BasicIconFactory__244$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$nonrefs	_jc_javax_swing_plaf_basic_BasicIconFactory__244$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object	_jc_javax_swing_plaf_basic_BasicIconFactory__244$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$vmethods	_jc_javax_swing_plaf_basic_BasicIconFactory__244$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$vtable	_jc_javax_swing_plaf_basic_BasicIconFactory__244$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$vtype	_jc_javax_swing_plaf_basic_BasicIconFactory__244$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicIconFactory__244$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_plaf_basic_BasicIconFactory__244$method$getIconHeight$50a8d095671b871d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_plaf_basic_BasicIconFactory__244$method$getIconWidth$e4e0e0a5d8773e91(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicIconFactory__244$method$paintIcon$ec942e304ba768a4(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicIconFactory__244$method_info$getIconHeight$50a8d095671b871d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicIconFactory__244$method_info$getIconWidth$e4e0e0a5d8773e91;
extern _jc_method _jc_javax_swing_plaf_basic_BasicIconFactory__244$method_info$paintIcon$ec942e304ba768a4;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$vmethods {
	jint	(*getIconHeight$50a8d095671b871d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object *) _JC_JCNI_ATTR;
	jint	(*getIconWidth$e4e0e0a5d8773e91)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object *) _JC_JCNI_ATTR;
	void	(*paintIcon$ec942e304ba768a4)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicIconFactory__244$vmethods	javax_swing_plaf_basic_BasicIconFactory__244;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicIconFactory__244$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$refs {
    _jc_javax_swing_plaf_basic_BasicIconFactory__244$sub_refs	javax_swing_plaf_basic_BasicIconFactory__244;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicIconFactory__244$sub_nonrefs	javax_swing_plaf_basic_BasicIconFactory__244;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicIconFactory__244$object {
	_jc_javax_swing_plaf_basic_BasicIconFactory__244$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicIconFactory__244$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicIconFactory__244$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicIconFactory__244$vtype _jc_javax_swing_plaf_basic_BasicIconFactory__244$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicIconFactory__244, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicIconFactory__244$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicIconFactory__244_H_ */
